@@ -1,5 +1,6 @@
 from inspect import currentframe, getouterframes
 from operator import attrgetter
+from pathlib import Path
 
 
 # Full Qualified Name od obj
@@ -16,7 +17,10 @@ def fqn(obj):
 
 # caller's caller
 def caller():
-    return getouterframes(currentframe(), 2)[2].function
+    frame = getouterframes(currentframe(), 2)[2]
+    mod = Path(frame.filename).stem
+    fct = frame.function
+    return f'{mod}.{fct}'
 
 
 # Default implementation for abstract methods
